"""Package 'playlist2podcast' level definitions."""
from typing import Final

__version__: Final[str] = "0.6.3"
__display_name__: Final[str] = "Playlist2Podcast"
__package_name__: Final[str] = __display_name__.lower()
